@@ -9,23 +9,26 @@ import (
 	"net/http"
 	"os"
 	"path"
-	"regexp"
+	"strconv"
 	"sync"
 	"time"
 
+	"github.com/caarlos0/env/v9"
 	"github.com/grafana/beyla/v2/pkg/beyla"
 	"github.com/grafana/beyla/v2/pkg/components"
 	beylaCfg "github.com/grafana/beyla/v2/pkg/config"
-	"github.com/grafana/beyla/v2/pkg/export/attributes"
-	"github.com/grafana/beyla/v2/pkg/export/debug"
-	"github.com/grafana/beyla/v2/pkg/export/prom"
-	"github.com/grafana/beyla/v2/pkg/filter"
-	"github.com/grafana/beyla/v2/pkg/kubeflags"
-	"github.com/grafana/beyla/v2/pkg/services"
-	"github.com/grafana/beyla/v2/pkg/transform"
+	beylaSvc "github.com/grafana/beyla/v2/pkg/services"
 	"github.com/prometheus/client_golang/prometheus"
 	"github.com/prometheus/client_golang/prometheus/promhttp"
 	"github.com/prometheus/common/model"
+	"go.opentelemetry.io/obi/pkg/export/attributes"
+	"go.opentelemetry.io/obi/pkg/export/debug"
+	"go.opentelemetry.io/obi/pkg/export/instrumentations"
+	"go.opentelemetry.io/obi/pkg/export/prom"
+	"go.opentelemetry.io/obi/pkg/filter"
+	"go.opentelemetry.io/obi/pkg/kubeflags"
+	"go.opentelemetry.io/obi/pkg/services"
+	"go.opentelemetry.io/obi/pkg/transform"
 	"golang.org/x/sync/errgroup" //nolint:depguard
 
 	"github.com/grafana/alloy/internal/component"
@@ -37,6 +40,7 @@ import (
 )
 
 func init() {
+	beyla.OverrideOBIGlobalConfig()
 	component.Register(component.Registration{
 		Name:      "beyla.ebpf",
 		Stability: featuregate.StabilityGenerallyAvailable,
@@ -61,6 +65,19 @@ type Component struct {
 
 var _ component.HealthComponent = (*Component)(nil)
 
+const (
+	SamplerAlwaysOn                = "always_on"
+	SamplerAlwaysOff               = "always_off"
+	SamplerTraceIDRatio            = "traceidratio"
+	SamplerParentBasedAlwaysOn     = "parentbased_always_on"
+	SamplerParentBasedAlwaysOff    = "parentbased_always_off"
+	SamplerParentBasedTraceIDRatio = "parentbased_traceidratio"
+)
+
+var validInstrumentations = map[string]struct{}{
+	"*": {}, "http": {}, "grpc": {}, "redis": {}, "kafka": {}, "sql": {}, "gpu": {}, "mongo": {},
+}
+
 func (args Routes) Convert() *transform.RoutesConfig {
 	routes := beyla.DefaultConfig.Routes
 	if args.Unmatch != "" {
@@ -75,6 +92,52 @@ func (args Routes) Convert() *transform.RoutesConfig {
 	return routes
 }
 
+func (args SamplerConfig) Validate() error {
+	if args.Name == "" {
+		return nil // Empty name is valid, will use default
+	}
+
+	validSamplers := map[string]bool{
+		SamplerAlwaysOn:                true,
+		SamplerAlwaysOff:               true,
+		SamplerTraceIDRatio:            true,
+		SamplerParentBasedAlwaysOn:     true,
+		SamplerParentBasedAlwaysOff:    true,
+		SamplerParentBasedTraceIDRatio: true,
+	}
+
+	if !validSamplers[args.Name] {
+		return fmt.Errorf("invalid sampler name %q. Valid values are: %s, %s, %s, %s, %s, %s", args.Name,
+			SamplerAlwaysOn, SamplerAlwaysOff, SamplerTraceIDRatio,
+			SamplerParentBasedAlwaysOn, SamplerParentBasedAlwaysOff, SamplerParentBasedTraceIDRatio)
+	}
+
+	// Validate arg for ratio-based samplers
+	if args.Name == SamplerTraceIDRatio || args.Name == SamplerParentBasedTraceIDRatio {
+		if args.Arg == "" {
+			return fmt.Errorf("sampler %q requires an arg parameter with a ratio value between 0 and 1", args.Name)
+		}
+
+		ratio, err := strconv.ParseFloat(args.Arg, 64)
+		if err != nil {
+			return fmt.Errorf("invalid arg %q for sampler %q: must be a valid decimal number", args.Arg, args.Name)
+		}
+
+		if ratio < 0 || ratio > 1 {
+			return fmt.Errorf("invalid arg %q for sampler %q: ratio must be between 0 and 1 (inclusive)", args.Arg, args.Name)
+		}
+	}
+
+	return nil
+}
+
+func (args SamplerConfig) Convert() services.SamplerConfig {
+	return services.SamplerConfig{
+		Name: args.Name,
+		Arg:  args.Arg,
+	}
+}
+
 func (args Attributes) Convert() beyla.Attributes {
 	attrs := beyla.DefaultConfig.Attributes
 	// Kubernetes
@@ -113,10 +176,10 @@ func (args Selections) Convert() attributes.Selection {
 	return s
 }
 
-func (args Discovery) Convert() (services.DiscoveryConfig, error) {
+func (args Discovery) Convert() (beylaSvc.BeylaDiscoveryConfig, error) {
 	d := beyla.DefaultConfig.Discovery
 
-	// Services
+	// Services (deprecated)
 	srv, err := args.Services.Convert()
 	if err != nil {
 		return d, err
@@ -135,6 +198,30 @@ func (args Discovery) Convert() (services.DiscoveryConfig, error) {
 		d.DefaultExcludeServices = defaultExcludeSrv
 	}
 
+	if len(args.Instrument) > 0 {
+		instrument, err := args.Instrument.ConvertGlob()
+		if err != nil {
+			return d, err
+		}
+		d.Instrument = instrument
+	}
+
+	if len(args.ExcludeInstrument) > 0 {
+		excludeInstrument, err := args.ExcludeInstrument.ConvertGlob()
+		if err != nil {
+			return d, err
+		}
+		d.ExcludeInstrument = excludeInstrument
+	}
+
+	if len(args.DefaultExcludeInstrument) > 0 {
+		defaultExcludeInstrument, err := args.DefaultExcludeInstrument.ConvertGlob()
+		if err != nil {
+			return d, err
+		}
+		d.DefaultExcludeInstrument = defaultExcludeInstrument
+	}
+
 	// Survey
 	survey, err := args.Survey.ConvertGlob()
 	if err != nil {
@@ -150,33 +237,55 @@ func (args Discovery) Convert() (services.DiscoveryConfig, error) {
 	return d, nil
 }
 
+func convertExportModes(modes []string) (services.ExportModes, error) {
+	if modes == nil {
+		return services.ExportModeUnset, nil
+	}
+
+	ret := services.NewExportModes()
+
+	for _, m := range modes {
+		switch m {
+		case "metrics":
+			ret.AllowMetrics()
+		case "traces":
+			ret.AllowTraces()
+		default:
+			return ret, fmt.Errorf("invalid export mode: '%s'", m)
+		}
+	}
+
+	return ret, nil
+}
+
 func serviceConvert[Attr any](
 	s Service,
 	convertFunc func(string) (Attr, error),
-	convertKubernetesFunc func(KubernetesService) (map[string]*Attr, error)) (services.PortEnum, Attr, map[string]*Attr, map[string]*Attr, map[string]*Attr, error) {
+	convertKubernetesFunc func(KubernetesService) (map[string]*Attr, error)) (services.PortEnum, Attr, map[string]*Attr, map[string]*Attr, map[string]*Attr, services.ExportModes, error) {
 
 	var paths Attr
 	var kubernetes map[string]*Attr
 	var podLabels map[string]*Attr
 	var podAnnotations map[string]*Attr
+	var exportModes services.ExportModes
 
 	ports, err := stringToPortEnum(s.OpenPorts)
 	if err != nil {
-		return ports, paths, kubernetes, podLabels, podAnnotations, err
+		return ports, paths, kubernetes, podLabels, podAnnotations, exportModes, err
 	}
 	paths, err = convertFunc(s.Path)
 	if err != nil {
-		return ports, paths, kubernetes, podLabels, podAnnotations, err
+		return ports, paths, kubernetes, podLabels, podAnnotations, exportModes, err
 	}
 	kubernetes, err = convertKubernetesFunc(s.Kubernetes)
 	if err != nil {
-		return ports, paths, kubernetes, podLabels, podAnnotations, err
+		return ports, paths, kubernetes, podLabels, podAnnotations, exportModes, err
 	}
 	podLabels = map[string]*Attr{}
 	for k, v := range s.Kubernetes.PodLabels {
 		label, err := convertFunc(v)
 		if err != nil {
-			return ports, paths, kubernetes, podLabels, podAnnotations, err
+			return ports, paths, kubernetes, podLabels, podAnnotations, exportModes, err
 		}
 		podLabels[k] = &label
 	}
@@ -185,17 +294,24 @@ func serviceConvert[Attr any](
 	for k, v := range s.Kubernetes.PodAnnotations {
 		annotation, err := convertFunc(v)
 		if err != nil {
-			return ports, paths, kubernetes, podLabels, podAnnotations, err
+			return ports, paths, kubernetes, podLabels, podAnnotations, exportModes, err
 		}
 		podAnnotations[k] = &annotation
 	}
-	return ports, paths, kubernetes, podLabels, podAnnotations, nil
+
+	exportModes, err = convertExportModes(s.ExportModes)
+
+	if err != nil {
+		return ports, paths, kubernetes, podLabels, podAnnotations, exportModes, err
+	}
+
+	return ports, paths, kubernetes, podLabels, podAnnotations, exportModes, nil
 }
 
 func (args Services) Convert() (services.RegexDefinitionCriteria, error) {
 	var attrs services.RegexDefinitionCriteria
 	for _, s := range args {
-		ports, paths, kubernetes, podLabels, podAnnotations, err := serviceConvert(
+		ports, paths, kubernetes, podLabels, podAnnotations, exportModes, err := serviceConvert(
 			s,
 			stringToRegexpAttr,
 			convertKubernetes,
@@ -205,6 +321,11 @@ func (args Services) Convert() (services.RegexDefinitionCriteria, error) {
 			return nil, err
 		}
 
+		var samplerConfig *services.SamplerConfig
+		if s.Sampler.Name != "" || s.Sampler.Arg != "" {
+			config := s.Sampler.Convert()
+			samplerConfig = &config
+		}
 		attrs = append(attrs, services.RegexSelector{
 			Name:           s.Name,
 			Namespace:      s.Namespace,
@@ -214,6 +335,8 @@ func (args Services) Convert() (services.RegexDefinitionCriteria, error) {
 			PodLabels:      podLabels,
 			ContainersOnly: s.ContainersOnly,
 			PodAnnotations: podAnnotations,
+			ExportModes:    exportModes,
+			SamplerConfig:  samplerConfig,
 		})
 	}
 	return attrs, nil
@@ -222,7 +345,7 @@ func (args Services) Convert() (services.RegexDefinitionCriteria, error) {
 func (args Services) ConvertGlob() (services.GlobDefinitionCriteria, error) {
 	var attrs services.GlobDefinitionCriteria
 	for _, s := range args {
-		ports, paths, kubernetes, podLabels, podAnnotations, err := serviceConvert(
+		ports, paths, kubernetes, podLabels, podAnnotations, exportModes, err := serviceConvert(
 			s,
 			stringToGlobAttr,
 			convertKubernetesGlob,
@@ -232,6 +355,11 @@ func (args Services) ConvertGlob() (services.GlobDefinitionCriteria, error) {
 			return nil, err
 		}
 
+		var samplerConfig *services.SamplerConfig
+		if s.Sampler.Name != "" || s.Sampler.Arg != "" {
+			config := s.Sampler.Convert()
+			samplerConfig = &config
+		}
 		attrs = append(attrs, services.GlobAttributes{
 			Name:           s.Name,
 			Namespace:      s.Namespace,
@@ -241,6 +369,8 @@ func (args Services) ConvertGlob() (services.GlobDefinitionCriteria, error) {
 			PodLabels:      podLabels,
 			ContainersOnly: s.ContainersOnly,
 			PodAnnotations: podAnnotations,
+			ExportModes:    exportModes,
+			SamplerConfig:  samplerConfig,
 		})
 	}
 	return attrs, nil
@@ -329,7 +459,8 @@ func (args Metrics) hasNetworkFeature() bool {
 func (args Metrics) hasAppFeature() bool {
 	for _, feature := range args.Features {
 		switch feature {
-		case "application", "application_host", "application_span", "application_service_graph", "application_process":
+		case "application", "application_host", "application_span", "application_service_graph",
+			"application_process", "application_span_otel", "application_span_sizes":
 			return true
 		}
 	}
@@ -337,9 +468,6 @@ func (args Metrics) hasAppFeature() bool {
 }
 
 func (args Metrics) Validate() error {
-	validInstrumentations := map[string]struct{}{
-		"*": {}, "http": {}, "grpc": {}, "redis": {}, "kafka": {}, "sql": {},
-	}
 	for _, instrumentation := range args.Instrumentations {
 		if _, ok := validInstrumentations[instrumentation]; !ok {
 			return fmt.Errorf("metrics.instrumentations: invalid value %q", instrumentation)
@@ -347,7 +475,8 @@ func (args Metrics) Validate() error {
 	}
 
 	validFeatures := map[string]struct{}{
-		"application": {}, "application_span": {}, "application_host": {},
+		"application": {}, "application_span": {}, "application_span_otel": {},
+		"application_span_sizes": {}, "application_host": {},
 		"application_service_graph": {}, "application_process": {},
 		"network": {}, "network_inter_zone": {},
 	}
@@ -452,6 +581,31 @@ func New(opts component.Options, args Arguments) (*Component, error) {
 	return c, nil
 }
 
+func (c *Component) loadConfig() (*beyla.Config, error) {
+	c.mut.Lock()
+	defer c.mut.Unlock()
+
+	cfg, err := c.args.Convert()
+	if err != nil {
+		return nil, fmt.Errorf("failed to convert arguments: %w", err)
+	}
+
+	if err := env.Parse(cfg); err != nil {
+		return nil, fmt.Errorf("failed to parse env: %w", err)
+	}
+
+	if cfg.Discovery.SurveyEnabled() {
+		cfg.Discovery.OverrideDefaultExcludeForSurvey()
+	}
+
+	c.reg = prometheus.NewRegistry()
+	c.reportHealthy()
+
+	cfg.Prometheus.Registry = c.reg
+
+	return cfg, nil
+}
+
 // Run implements component.Component.
 func (c *Component) Run(ctx context.Context) error {
 	// Add deprecation warnings at the start of Run
@@ -462,6 +616,17 @@ func (c *Component) Run(ctx context.Context) error {
 		level.Warn(c.opts.Logger).Log("msg", "The 'executable_name' field is deprecated. Use 'discovery.services' instead.")
 	}
 
+	// Add deprecation warnings for legacy discovery fields
+	if len(c.args.Discovery.Services) > 0 {
+		level.Warn(c.opts.Logger).Log("msg", "discovery.services is deprecated, use discovery.instrument instead")
+	}
+	if len(c.args.Discovery.ExcludeServices) > 0 {
+		level.Warn(c.opts.Logger).Log("msg", "discovery.exclude_services is deprecated, use discovery.exclude_instrument instead")
+	}
+	if len(c.args.Discovery.DefaultExcludeServices) > 0 {
+		level.Warn(c.opts.Logger).Log("msg", "discovery.default_exclude_services is deprecated, use discovery.default_exclude_instrument instead")
+	}
+
 	var cancel context.CancelFunc
 	var cancelG *errgroup.Group
 	for {
@@ -476,9 +641,8 @@ func (c *Component) Run(ctx context.Context) error {
 				cancel()
 				level.Info(c.opts.Logger).Log("msg", "waiting for Beyla to terminate")
 				if err := cancelG.Wait(); err != nil {
-					level.Error(c.opts.Logger).Log("msg", "failed to terminate Beyla", "err", err)
+					level.Error(c.opts.Logger).Log("msg", "Beyla terminated with error", "err", err)
 					c.reportUnhealthy(err)
-					return err
 				}
 			}
 
@@ -487,18 +651,12 @@ func (c *Component) Run(ctx context.Context) error {
 			newCtx, cancelFunc := context.WithCancel(ctx)
 			cancel = cancelFunc
 
-			c.mut.Lock()
-			cfg, err := c.args.Convert()
+			cfg, err := c.loadConfig()
 			if err != nil {
-				level.Error(c.opts.Logger).Log("msg", "failed to convert arguments", "err", err)
+				level.Error(c.opts.Logger).Log("msg", "failed to load config", "err", err)
 				c.reportUnhealthy(err)
-				c.mut.Unlock()
 				continue
 			}
-			c.reg = prometheus.NewRegistry()
-			c.reportHealthy()
-			cfg.Prometheus.Registry = c.reg
-			c.mut.Unlock()
 
 			g, launchCtx := errgroup.WithContext(newCtx)
 			cancelG = g
@@ -592,9 +750,11 @@ func (c *Component) Handler() http.Handler {
 func (a *Arguments) Convert() (*beyla.Config, error) {
 	var err error
 	cfg := beyla.DefaultConfig
+
 	if a.Output != nil {
-		cfg.TracesReceiver = convertTraceConsumers(a.Output.Traces)
+		cfg.TracesReceiver = a.Traces.Convert(a.Output.Traces)
 	}
+
 	cfg.Routes = a.Routes.Convert()
 	cfg.Attributes = a.Attributes.Convert()
 	cfg.Discovery, err = a.Discovery.Convert()
@@ -639,39 +799,139 @@ func (args *Arguments) Validate() error {
 		return err
 	}
 
-	if hasAppFeature {
-		if len(args.Discovery.Services) == 0 && len(args.Discovery.Survey) == 0 {
-			return fmt.Errorf("discovery.services or discovery.survey is required when application features are enabled")
+	if err := args.Traces.Validate(); err != nil {
+		return err
+	}
+
+	// If traces block is defined with instrumentations, output section must be defined
+	if len(args.Traces.Instrumentations) > 0 || args.Traces.Sampler.Name != "" {
+		if args.Output == nil {
+			return fmt.Errorf("traces block is defined but output section is missing. When using traces configuration, you must define an output block")
 		}
+	}
+
+	if hasAppFeature {
+		// Check if any discovery method is configured (new or legacy)
+		hasAnyDiscovery := len(args.Discovery.Services) > 0 ||
+			len(args.Discovery.Survey) > 0 ||
+			len(args.Discovery.Instrument) > 0
+
+		if !hasAnyDiscovery {
+			return fmt.Errorf("discovery.services, discovery.instrument, or discovery.survey is required when application features are enabled")
+		}
+
+		// Validate legacy services field
 		if len(args.Discovery.Services) > 0 {
 			if err := args.Discovery.Services.Validate(); err != nil {
 				return fmt.Errorf("invalid discovery configuration: %s", err.Error())
 			}
 		}
+
+		// Validate survey field
 		if len(args.Discovery.Survey) > 0 {
 			if err := args.Discovery.Survey.Validate(); err != nil {
 				return fmt.Errorf("invalid survey configuration: %s", err.Error())
 			}
 		}
+
+		// Validate new instrument field
+		if len(args.Discovery.Instrument) > 0 {
+			if err := args.Discovery.Instrument.Validate(); err != nil {
+				return fmt.Errorf("invalid instrument configuration: %s", err.Error())
+			}
+		}
 	}
 
+	// Validate legacy exclude_services field
 	if len(args.Discovery.ExcludeServices) > 0 {
 		if err := args.Discovery.ExcludeServices.Validate(); err != nil {
 			return fmt.Errorf("invalid exclude_services configuration: %s", err.Error())
 		}
 	}
+
+	// Validate new exclude_instrument field
+	if len(args.Discovery.ExcludeInstrument) > 0 {
+		if err := args.Discovery.ExcludeInstrument.Validate(); err != nil {
+			return fmt.Errorf("invalid exclude_instrument configuration: %s", err.Error())
+		}
+	}
+
+	// Validate new default_exclude_instrument field
+	if len(args.Discovery.DefaultExcludeInstrument) > 0 {
+		if err := args.Discovery.DefaultExcludeInstrument.Validate(); err != nil {
+			return fmt.Errorf("invalid default_exclude_instrument configuration: %s", err.Error())
+		}
+	}
+
+	// Validate per-service samplers for legacy services
+	for i, service := range args.Discovery.Services {
+		if err := service.Sampler.Validate(); err != nil {
+			return fmt.Errorf("invalid sampler configuration in discovery.services[%d]: %s", i, err.Error())
+		}
+	}
+
+	// Validate per-service samplers for new instrument field
+	for i, service := range args.Discovery.Instrument {
+		if err := service.Sampler.Validate(); err != nil {
+			return fmt.Errorf("invalid sampler configuration in discovery.instrument[%d]: %s", i, err.Error())
+		}
+	}
+
+	// Validate per-service samplers for survey field
+	for i, service := range args.Discovery.Survey {
+		if err := service.Sampler.Validate(); err != nil {
+			return fmt.Errorf("invalid sampler configuration in discovery.survey[%d]: %s", i, err.Error())
+		}
+	}
+
+	return nil
+}
+
+func (args Traces) Convert(consumers []otelcol.Consumer) beyla.TracesReceiverConfig {
+	// Convert the OTEL consumers
+	convertedConsumers := make([]beyla.Consumer, len(consumers))
+	for i, trace := range consumers {
+		convertedConsumers[i] = trace
+	}
+
+	config := beyla.TracesReceiverConfig{
+		Traces: convertedConsumers,
+	}
+
+	if len(args.Instrumentations) == 0 {
+		config.Instrumentations = []string{
+			instrumentations.InstrumentationALL,
+		}
+	} else {
+		config.Instrumentations = args.Instrumentations
+	}
+	if args.Sampler.Name != "" || args.Sampler.Arg != "" {
+		config.Sampler = args.Sampler.Convert()
+	}
+	return config
+}
+
+func (args Traces) Validate() error {
+	for _, instrumentation := range args.Instrumentations {
+		if _, ok := validInstrumentations[instrumentation]; !ok {
+			return fmt.Errorf("traces.instrumentations: invalid value %q", instrumentation)
+		}
+	}
+
+	// Validate the global sampler config
+	if err := args.Sampler.Validate(); err != nil {
+		return fmt.Errorf("invalid global sampler configuration: %s", err.Error())
+	}
+
 	return nil
 }
 
 func stringToRegexpAttr(s string) (services.RegexpAttr, error) {
-	if s == "" {
-		return services.RegexpAttr{}, nil
-	}
-	re, err := regexp.Compile(s)
-	if err != nil {
+	var attr services.RegexpAttr
+	if err := attr.UnmarshalText([]byte(s)); err != nil {
 		return services.RegexpAttr{}, err
 	}
-	return services.NewPathRegexp(re), nil
+	return attr, nil
 }
 
 func stringToGlobAttr(s string) (services.GlobAttr, error) {
@@ -700,16 +960,6 @@ func stringToPortEnum(s string) (services.PortEnum, error) {
 	return p, nil
 }
 
-func convertTraceConsumers(consumers []otelcol.Consumer) beyla.TracesReceiverConfig {
-	convertedConsumers := make([]beyla.Consumer, len(consumers))
-	for i, trace := range consumers {
-		convertedConsumers[i] = trace
-	}
-	return beyla.TracesReceiverConfig{
-		Traces: convertedConsumers,
-	}
-}
-
 func defaultInstance() string {
 	hostname := os.Getenv("HOSTNAME")
 	if hostname != "" {
