@@ -369,16 +369,17 @@ func populateSpanEvents(zspan *zipkinmodel.SpanModel, events ptrace.SpanEventSli
 
 func jsonMapToAttributeMap(attrs map[string]any, dest pcommon.Map) error {
 	for key, val := range attrs {
-		if s, ok := val.(string); ok {
-			dest.PutStr(key, s)
-		} else if d, ok := val.(float64); ok {
-			if math.Mod(d, 1.0) == 0.0 {
-				dest.PutInt(key, int64(d))
+		switch cast := val.(type) {
+		case string:
+			dest.PutStr(key, cast)
+		case float64:
+			if math.Mod(cast, 1.0) == 0.0 {
+				dest.PutInt(key, int64(cast))
 			} else {
-				dest.PutDouble(key, d)
+				dest.PutDouble(key, cast)
 			}
-		} else if b, ok := val.(bool); ok {
-			dest.PutBool(key, b)
+		case bool:
+			dest.PutBool(key, cast)
 		}
 	}
 	return nil
@@ -528,7 +529,7 @@ func setTimestampsV2(zspan *zipkinmodel.SpanModel, dest ptrace.Span, destAttrs p
 
 // unmarshalJSON inflates trace id from hex string, possibly enclosed in quotes.
 // TODO: Find a way to avoid this duplicate code. Consider to expose this in pdata.
-func unmarshalJSON(dst []byte, src []byte) error {
+func unmarshalJSON(dst, src []byte) error {
 	if l := len(src); l >= 2 && src[0] == '"' && src[l-1] == '"' {
 		src = src[1 : l-1]
 	}
