@@ -7,6 +7,7 @@ import (
 	"context"
 	"errors"
 	"fmt"
+	"maps"
 	"regexp"
 	"strings"
 	"sync"
@@ -45,6 +46,9 @@ const (
 	// Semconv attributes https://github.com/open-telemetry/semantic-conventions/blob/main/docs/resource/k8s.md#deployment
 	K8sDeploymentLabel      = "k8s.deployment.label.%s"
 	K8sDeploymentAnnotation = "k8s.deployment.annotation.%s"
+	// Semconv attributes https://github.com/open-telemetry/semantic-conventions/blob/main/docs/resource/k8s.md#statefulset
+	K8sStatefulSetLabel      = "k8s.statefulset.label.%s"
+	K8sStatefulSetAnnotation = "k8s.statefulset.annotation.%s"
 )
 
 // WatchClient is the main interface provided by this package to a kubernetes cluster.
@@ -57,6 +61,7 @@ type WatchClient struct {
 	namespaceInformer      cache.SharedInformer
 	nodeInformer           cache.SharedInformer
 	deploymentInformer     cache.SharedInformer
+	statefulsetInformer    cache.SharedInformer
 	replicasetInformer     cache.SharedInformer
 	replicasetRegex        *regexp.Regexp
 	cronJobRegex           *regexp.Regexp
@@ -85,6 +90,10 @@ type WatchClient struct {
 	// Key is deployment uid
 	Deployments map[string]*Deployment
 
+	// A map containing StatefulSet related data, used to associate them with resources.
+	// Key is statefulset uid
+	StatefulSets map[string]*StatefulSet
+
 	// A map containing ReplicaSets related data, used to associate them with resources.
 	// Key is replicaset uid
 	ReplicaSets map[string]*ReplicaSet
@@ -98,7 +107,7 @@ var rRegex = regexp.MustCompile(`^(.*)-[0-9a-zA-Z]+$`)
 
 // Extract CronJob name from the Job name. Job name is created using
 // format: [cronjob-name]-[time-hash-int]
-var cronJobRegex = regexp.MustCompile(`^(.*)-[0-9]+$`)
+var cronJobRegex = regexp.MustCompile(`^(.*)-\d+$`)
 
 var errCannotRetrieveImage = errors.New("cannot retrieve image name")
 
@@ -145,6 +154,7 @@ func New(
 	c.Nodes = map[string]*Node{}
 	c.ReplicaSets = map[string]*ReplicaSet{}
 	c.Deployments = map[string]*Deployment{}
+	c.StatefulSets = map[string]*StatefulSet{}
 	if newClientSet == nil {
 		newClientSet = k8sconfig.MakeClient
 	}
@@ -228,6 +238,10 @@ func New(
 		c.deploymentInformer = newDeploymentSharedInformer(c.kc, c.Filters.Namespace)
 	}
 
+	if c.extractStatefulSetLabelsAnnotations() {
+		c.statefulsetInformer = newStatefulSetSharedInformer(c.kc, c.Filters.Namespace)
+	}
+
 	return c, err
 }
 
@@ -286,6 +300,19 @@ func (c *WatchClient) Start() error {
 		go c.deploymentInformer.Run(c.stopCh)
 	}
 
+	if c.statefulsetInformer != nil {
+		reg, err = c.statefulsetInformer.AddEventHandler(cache.ResourceEventHandlerFuncs{
+			AddFunc:    c.handleStatefulSetAdd,
+			UpdateFunc: c.handleStatefulSetUpdate,
+			DeleteFunc: c.handleStatefulSetDelete,
+		})
+		if err != nil {
+			return err
+		}
+		synced = append(synced, reg.HasSynced)
+		go c.statefulsetInformer.Run(c.stopCh)
+	}
+
 	reg, err = c.informer.AddEventHandler(cache.ResourceEventHandlerFuncs{
 		AddFunc:    c.handlePodAdd,
 		UpdateFunc: c.handlePodUpdate,
@@ -449,7 +476,38 @@ func (c *WatchClient) handleDeploymentDelete(obj any) {
 	}
 }
 
-func (c *WatchClient) deleteLoop(interval time.Duration, gracePeriod time.Duration) {
+func (c *WatchClient) handleStatefulSetAdd(obj any) {
+	c.telemetryBuilder.OtelsvcK8sStatefulsetAdded.Add(context.Background(), 1)
+	if statefulset, ok := obj.(*apps_v1.StatefulSet); ok {
+		c.addOrUpdateStatefulSet(statefulset)
+	} else {
+		c.logger.Error("object received was not of type api_v1.StatefulSet", zap.Any("received", obj))
+	}
+}
+
+func (c *WatchClient) handleStatefulSetUpdate(_, newStatefulSet any) {
+	c.telemetryBuilder.OtelsvcK8sStatefulsetUpdated.Add(context.Background(), 1)
+	if statefulset, ok := newStatefulSet.(*apps_v1.StatefulSet); ok {
+		c.addOrUpdateStatefulSet(statefulset)
+	} else {
+		c.logger.Error("object received was not of type api_v1.StatefulSet", zap.Any("received", newStatefulSet))
+	}
+}
+
+func (c *WatchClient) handleStatefulSetDelete(obj any) {
+	c.telemetryBuilder.OtelsvcK8sStatefulsetDeleted.Add(context.Background(), 1)
+	if statefulset, ok := ignoreDeletedFinalStateUnknown(obj).(*apps_v1.StatefulSet); ok {
+		c.m.Lock()
+		if n, ok := c.StatefulSets[string(statefulset.UID)]; ok {
+			delete(c.StatefulSets, n.UID)
+		}
+		c.m.Unlock()
+	} else {
+		c.logger.Error("object received was not of type api_v1.StatefulSet", zap.Any("received", obj))
+	}
+}
+
+func (c *WatchClient) deleteLoop(interval, gracePeriod time.Duration) {
 	// This loop runs after N seconds and deletes pods from cache.
 	// It iterates over the delete queue and deletes all that aren't
 	// in the grace period anymore.
@@ -536,6 +594,16 @@ func (c *WatchClient) GetDeployment(deploymentUID string) (*Deployment, bool) {
 	return nil, false
 }
 
+func (c *WatchClient) GetStatefulSet(statefulSetUID string) (*StatefulSet, bool) {
+	c.m.RLock()
+	statefulSet, ok := c.StatefulSets[statefulSetUID]
+	c.m.RUnlock()
+	if ok {
+		return statefulSet, ok
+	}
+	return nil, false
+}
+
 func (c *WatchClient) extractPodAttributes(pod *api_v1.Pod) map[string]string {
 	tags := map[string]string{}
 	if c.Rules.PodName {
@@ -557,6 +625,10 @@ func (c *WatchClient) extractPodAttributes(pod *api_v1.Pod) map[string]string {
 		tags[string(conventions.K8SNamespaceNameKey)] = pod.GetNamespace()
 	}
 
+	if c.Rules.ServiceNamespace {
+		tags[string(conventions.ServiceNamespaceKey)] = pod.GetNamespace()
+	}
+
 	if c.Rules.StartTime {
 		ts := pod.GetCreationTimestamp()
 		if !ts.IsZero() {
@@ -937,16 +1009,31 @@ func (c *WatchClient) extractDeploymentAttributes(d *apps_v1.Deployment) map[str
 	return tags
 }
 
+func (c *WatchClient) extractStatefulSetAttributes(d *apps_v1.StatefulSet) map[string]string {
+	tags := map[string]string{}
+
+	for _, r := range c.Rules.Labels {
+		r.extractFromStatefulSetMetadata(d.Labels, tags, K8sStatefulSetLabel)
+	}
+
+	for _, r := range c.Rules.Annotations {
+		r.extractFromStatefulSetMetadata(d.Annotations, tags, K8sStatefulSetAnnotation)
+	}
+
+	return tags
+}
+
 func (c *WatchClient) podFromAPI(pod *api_v1.Pod) *Pod {
 	newPod := &Pod{
-		Name:          pod.Name,
-		Namespace:     pod.GetNamespace(),
-		NodeName:      pod.Spec.NodeName,
-		DeploymentUID: "",
-		Address:       pod.Status.PodIP,
-		HostNetwork:   pod.Spec.HostNetwork,
-		PodUID:        string(pod.UID),
-		StartTime:     pod.Status.StartTime,
+		Name:           pod.Name,
+		Namespace:      pod.GetNamespace(),
+		NodeName:       pod.Spec.NodeName,
+		DeploymentUID:  "",
+		StatefulSetUID: "",
+		Address:        pod.Status.PodIP,
+		HostNetwork:    pod.Spec.HostNetwork,
+		PodUID:         string(pod.UID),
+		StartTime:      pod.Status.StartTime,
 	}
 
 	if replicaset, ok := c.getReplicaSet(getPodReplicaSetUID(pod)); ok {
@@ -955,6 +1042,10 @@ func (c *WatchClient) podFromAPI(pod *api_v1.Pod) *Pod {
 		}
 	}
 
+	if statefulset, ok := c.getStatefulSet(getPodStatefulSetUID(pod)); ok {
+		newPod.StatefulSetUID = statefulset.UID
+	}
+
 	if c.shouldIgnorePod(pod) {
 		newPod.Ignore = true
 	} else {
@@ -976,10 +1067,20 @@ func getPodReplicaSetUID(pod *api_v1.Pod) string {
 	return ""
 }
 
+func getPodStatefulSetUID(pod *api_v1.Pod) string {
+	for _, ref := range pod.OwnerReferences {
+		if ref.Kind == "StatefulSet" {
+			return string(ref.UID)
+		}
+	}
+	return ""
+}
+
 // getIdentifiersFromAssoc returns list of PodIdentifiers for given pod
 func (c *WatchClient) getIdentifiersFromAssoc(pod *Pod) []PodIdentifier {
 	var ids []PodIdentifier
 	for _, assoc := range c.Associations {
+		retID4containerID := -1
 		ret := PodIdentifier{}
 		skip := false
 		for i, source := range assoc.Sources {
@@ -1013,13 +1114,17 @@ func (c *WatchClient) getIdentifiersFromAssoc(pod *Pod) []PodIdentifier {
 				// k8s.pod.ip is set by passthrough mode
 				case K8sIPLabelName:
 					attr = pod.Address
+				case string(conventions.ContainerIDKey):
+					// At this point just an empty attr is added and we remember the position.
+					// Later this position in PodIdentifier will be filled with the actual
+					// value for container.ID.
+					retID4containerID = i
 				default:
 					if v, ok := pod.Attributes[source.Name]; ok {
 						attr = v
 					}
 				}
-
-				if attr == "" {
+				if attr == "" && retID4containerID == -1 {
 					skip = true
 					break
 				}
@@ -1028,7 +1133,21 @@ func (c *WatchClient) getIdentifiersFromAssoc(pod *Pod) []PodIdentifier {
 		}
 
 		if !skip {
-			ids = append(ids, ret)
+			if retID4containerID != -1 {
+				// As there can be multiple container.IDs per pod,
+				// one PodIdentifier is added per container.ID.
+				cIDs := maps.Keys(pod.Containers.ByID)
+				for cID := range cIDs {
+					retCpy := ret
+					retCpy[retID4containerID] = PodIdentifierAttributeFromSource(AssociationSource{
+						From: ResourceSource,
+						Name: string(conventions.ContainerIDKey),
+					}, cID)
+					ids = append(ids, retCpy)
+				}
+			} else {
+				ids = append(ids, ret)
+			}
 		}
 	}
 
@@ -1040,13 +1159,14 @@ func (c *WatchClient) getIdentifiersFromAssoc(pod *Pod) []PodIdentifier {
 	}
 
 	if pod.Address != "" && !pod.HostNetwork {
-		ids = append(ids, PodIdentifier{
-			PodIdentifierAttributeFromConnection(pod.Address),
-		})
-		// k8s.pod.ip is set by passthrough mode
-		ids = append(ids, PodIdentifier{
-			PodIdentifierAttributeFromResourceAttribute(K8sIPLabelName, pod.Address),
-		})
+		ids = append(ids,
+			PodIdentifier{
+				PodIdentifierAttributeFromConnection(pod.Address),
+			},
+			// k8s.pod.ip is set by passthrough mode
+			PodIdentifier{
+				PodIdentifierAttributeFromResourceAttribute(K8sIPLabelName, pod.Address),
+			})
 	}
 
 	return ids
@@ -1145,8 +1265,6 @@ func selectorsFromFilters(filters Filters) (labels.Selector, fields.Selector, er
 			selectors = append(selectors, fields.OneTermEqualSelector(f.Key, f.Value))
 		case selection.NotEquals:
 			selectors = append(selectors, fields.OneTermNotEqualSelector(f.Key, f.Value))
-		case selection.DoesNotExist, selection.DoubleEquals, selection.In, selection.NotIn, selection.Exists, selection.GreaterThan, selection.LessThan:
-			fallthrough
 		default:
 			return nil, nil, fmt.Errorf("field filters don't support operator: '%s'", f.Op)
 		}
@@ -1205,6 +1323,22 @@ func (c *WatchClient) extractDeploymentLabelsAnnotations() bool {
 	return false
 }
 
+func (c *WatchClient) extractStatefulSetLabelsAnnotations() bool {
+	for _, r := range c.Rules.Labels {
+		if r.From == MetadataFromStatefulSet {
+			return true
+		}
+	}
+
+	for _, r := range c.Rules.Annotations {
+		if r.From == MetadataFromStatefulSet {
+			return true
+		}
+	}
+
+	return false
+}
+
 func (c *WatchClient) extractNodeLabelsAnnotations() bool {
 	for _, r := range c.Rules.Labels {
 		if r.From == MetadataFromNode {
@@ -1253,6 +1387,20 @@ func (c *WatchClient) addOrUpdateDeployment(deployment *apps_v1.Deployment) {
 	c.m.Unlock()
 }
 
+func (c *WatchClient) addOrUpdateStatefulSet(statefulset *apps_v1.StatefulSet) {
+	newStatefulSet := &StatefulSet{
+		Name: statefulset.Name,
+		UID:  string(statefulset.UID),
+	}
+	newStatefulSet.Attributes = c.extractStatefulSetAttributes(statefulset)
+
+	c.m.Lock()
+	if statefulset.UID != "" {
+		c.StatefulSets[string(statefulset.UID)] = newStatefulSet
+	}
+	c.m.Unlock()
+}
+
 func needContainerAttributes(rules ExtractionRules) bool {
 	return rules.ContainerImageName ||
 		rules.ContainerName ||
@@ -1340,6 +1488,16 @@ func (c *WatchClient) getReplicaSet(uid string) (*ReplicaSet, bool) {
 	return nil, false
 }
 
+func (c *WatchClient) getStatefulSet(uid string) (*StatefulSet, bool) {
+	c.m.RLock()
+	statefulset, ok := c.StatefulSets[uid]
+	c.m.RUnlock()
+	if ok {
+		return statefulset, ok
+	}
+	return nil, false
+}
+
 // runInformerWithDependencies starts the given informer. The second argument is a list of other informers that should complete
 // before the informer is started. This is necessary e.g. for the pod informer which requires the replica set informer
 // to be finished to correctly establish the connection to the replicaset/deployment it belongs to.
